# Changelog

## Version 0.2.0

- Implemented HyMiNoR
- more thresholding options in utils, and diff functions

## Version 0.1.2

- Implemented HyRes
- implemented DWT2D clone to use PyTorch with different dtypes and devices
